Module replay

Module replay 

Structs

ReplayError
Aggregate replay validation failure.
ReplayOptions
Replay behavior controls.
ReplayReport
Successful replay validation report.
ReplayViolation
A single replay validation violation.

Enums

ReplayCachePolicy
Cache policy used by replay workflows.
ReplayViolationCode
Stable replay validation codes.

Functions

replay_trace
Validates that a recorded trace can be structurally replayed.
replay_trace_with_options
Validates that a recorded trace can be structurally replayed with options.