pub struct DagScheduler { /* private fields */ }Expand description
Bounded async scheduler for DAG-adjacent fan-out workloads.
Implementations
Sourceimpl DagScheduler
impl DagScheduler
Sourcepub fn new(max_in_flight: usize) -> Self
pub fn new(max_in_flight: usize) -> Self
Creates a scheduler with a bounded number of concurrent tasks.
Sourcepub fn max_in_flight(self) -> usize
pub fn max_in_flight(self) -> usize
Returns the configured maximum number of in-flight tasks.
Sourcepub async fn run_bounded<I, F, Fut, T, E>(
&self,
inputs: I,
task_builder: F,
) -> Result<Vec<T>, E>
pub async fn run_bounded<I, F, Fut, T, E>( &self, inputs: I, task_builder: F, ) -> Result<Vec<T>, E>
Executes tasks with bounded concurrency and deterministic result ordering.