pub enum ScopeAccessError {
ReadDenied {
capability: &'static str,
},
WriteDenied {
capability: &'static str,
},
CannotExitRoot,
}Expand description
Typed read/write boundary failures for scoped runtime state.
Variants
ReadDenied
Node attempted to read scope with an invalid capability.
WriteDenied
Node attempted to write scope with an invalid capability.
CannotExitRoot
Attempted to exit root scope.