YamlWorkflowRunOutput

Struct YamlWorkflowRunOutput 

pub struct YamlWorkflowRunOutput {
Show 18 fields pub workflow_id: String, pub entry_node: String, pub trace: Vec<String>, pub outputs: BTreeMap<String, Value>, pub terminal_node: String, pub terminal_output: Option<Value>, pub step_timings: Vec<YamlStepTiming>, pub llm_node_metrics: BTreeMap<String, YamlLlmNodeMetrics>, pub llm_node_models: BTreeMap<String, String>, pub total_elapsed_ms: u128, pub ttft_ms: Option<u128>, pub total_input_tokens: u64, pub total_output_tokens: u64, pub total_tokens: u64, pub total_reasoning_tokens: Option<u64>, pub tokens_per_second: f64, pub trace_id: Option<String>, pub metadata: Option<Value>,
}

Fields

workflow_id: Stringentry_node: Stringtrace: Vec<String>outputs: BTreeMap<String, Value>terminal_node: Stringterminal_output: Option<Value>step_timings: Vec<YamlStepTiming>llm_node_metrics: BTreeMap<String, YamlLlmNodeMetrics>llm_node_models: BTreeMap<String, String>total_elapsed_ms: u128ttft_ms: Option<u128>total_input_tokens: u64total_output_tokens: u64total_tokens: u64total_reasoning_tokens: Option<u64>tokens_per_second: f64trace_id: Option<String>metadata: Option<Value>

Implementations

Source

impl YamlWorkflowRunOutput

pub fn to_typed_output( &self, workflow: &YamlWorkflow, ) -> YamlWorkflowRunTypedOutput

Project loose JSON output maps into explicit typed records.

This keeps node outputs and terminal output while intentionally omitting token aggregates, timings, and metadata from the typed surface.